/**
 * Copyright (c) 2014-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.api.configuration.exception;


/**
 * The domain configuration is inconsistent:
 * <ul>
 * <li>an error was detected about the topology: the domain mode is not supported,</li>
 * <li>or a new topology is not compliant, at domain level, with the current one, defining a different domain mode.</li>
 * </ul>
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class InconsistentDomainModeException extends InconsistentDomainConfigurationException {

    private static final long serialVersionUID = -5878089851234808198L;

    private final static String MESSAGE_TEMPLATE = "Inconsistent domain mode for domain '%s'";

    /**
     * The domain name having an unsupported or inconsistent mode
     */
    private final String domainName;

    public InconsistentDomainModeException(final String domainName) {
        super(String.format(MESSAGE_TEMPLATE, domainName));
        this.domainName = domainName;
    }

    /**
     * @return The domain name having an unsupported or inconsistent mode
     */
    public String getDomainName() {
        return this.domainName;
    }

}
