/**
 * Copyright (c) 2009-2012 EBM WebSourcing, 2012-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.api.container;

import java.io.IOException;

import javax.jbi.JBIException;
import javax.jbi.component.Component;
import javax.jbi.management.InstallerMBean;
import javax.management.ObjectName;
import javax.naming.NamingException;

import org.ow2.petals.basisapi.exception.PetalsException;
import org.ow2.petals.jbi.descriptor.original.generated.Jbi;
import org.ow2.petals.microkernel.api.jbi.component.PetalsComponentContext;
import org.ow2.petals.microkernel.api.jbi.management.Context;

/**
 * @author Roland Naudin - EBM WebSourcing
 * @author Christophe DENEUX - EBM Websourcing
 */
public interface Installer extends InstallerMBean {

    public static final String COMPONENT_LOGGER_NAME = "Petals.Container.Lifecycle.Installer";

    public static final String INSTALLED = "Installed";

    public static final String UNINSTALLED = "Uninstalled";

    /**
     * Name of the server interface of the Fractal component associated to the JBI component installer
     */
    public static final String FRACTAL_SRV_ITF_NAME = "service";

    /**
     * init the installer.
     * 
     * @param ctxt
     *            the context (installation context)
     * @throws IOException
     *             impossible initialization
     * @throws JBIException
     *             impossible initialization
     * @throws NamingException
     *             impossible initialization
     */
    void init(final Context ctxt) throws IOException, JBIException, NamingException;

    /**
     * Initialize the bootstrap of the JBI component. Invoked when loading a new installer of a JBI component or when
     * loading an existing installer (to uninstall a component).
     * 
     * @throws JBIException
     */
    public void initBootstrap() throws JBIException;

    /**
     * @return The JBI component associated to this installer
     */
    public Component getComponent();

    /**
     * @return The JBI identifier of the component associated to this installer
     */
    public String getComponentName();

    /**
     * @return the JBI descriptor of the component associated to this installer
     */
    public Jbi getJBIDescriptor();

    public IsolatingThread getComponentThread();

    public PetalsComponentContext getComponentContext();

    /**
     * Like {@link #install()} but used internally and returning the {@link ComponentLifeCycle} object instead of an
     * {@link ObjectName}.
     */
    public ComponentLifeCycle installInternal() throws JBIException;
}
